==> shellcheck-0.7.1-143-x86_64.pkg.tar.zst: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ShellCheck
version:              0.7.1
visibility:           public
id:                   ShellCheck-0.7.1-8RQeqku2ONM7lEQaA9Cgk5
key:                  ShellCheck-0.7.1-8RQeqku2ONM7lEQaA9Cgk5
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  ca3bf0810fcf40b172a4466e32877495
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.Custom
    ShellCheck.Checks.ShellSupport ShellCheck.Data ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-8.10.2/site-local/ShellCheck-0.7.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ShellCheck-0.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ShellCheck-0.7.1
hs-libraries:         HSShellCheck-0.7.1-8RQeqku2ONM7lEQaA9Cgk5
depends:
    Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    QuickCheck-2.14.1-54Nibp4SRVEEcNcBKSVQ1l
    aeson-1.5.4.0-5vxqgGZiwHzJS2LSOWy84c array-0.5.4.0 base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    process-1.6.9.0 regex-tdfa-1.3.1.0-AFxBgVqbB6pDA5wu8Xc5xC

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.7.1-152-x86_64.pkg.tar.zst: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ShellCheck
version:              0.7.1
visibility:           public
id:                   ShellCheck-0.7.1-6snA8bpEeDJptkSGgZ8JP
key:                  ShellCheck-0.7.1-6snA8bpEeDJptkSGgZ8JP
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  f4c7eeb0af4c920741bc4d5194b47122
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.Custom
    ShellCheck.Checks.ShellSupport ShellCheck.Data ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-8.10.2/site-local/ShellCheck-0.7.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ShellCheck-0.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ShellCheck-0.7.1
hs-libraries:         HSShellCheck-0.7.1-6snA8bpEeDJptkSGgZ8JP
depends:
    Diff-0.4.0-KyPtUOKlpskC2b7jcuQ1e4
    QuickCheck-2.14.1-HTGPGTiPlLFBv0MoTd9R3D
    aeson-1.5.4.1-2YgQvnoUGUbFY9GKPCy4dR array-0.5.4.0 base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    process-1.6.9.0 regex-tdfa-1.3.1.0-AFxBgVqbB6pDA5wu8Xc5xC

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
